@@ -1,4 +1,3 @@
-/* $Id: dotlock.h,v 1.3 1998/10/13 20:44:58 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * Copyright (C) 1998 Thomas Roessler <roessler@guug.de>
@@ -36,9 +35,12 @@
 #define DL_FL_USEPRIV	(1 << 2)
 #define DL_FL_FORCE	(1 << 3)
 #define DL_FL_RETRY	(1 << 4)
+#define DL_FL_UNLINK	(1 << 5)
+
+#define DL_FL_ACTIONS (DL_FL_TRY|DL_FL_UNLOCK|DL_FL_UNLINK)
 
 #ifndef DL_STANDALONE
-int dotlock_invoke(const char *, int, int);
+int dotlock_invoke (const char *, int, int);
 #endif
 
 #endif
