@@ -227,7 +227,8 @@ static void show_version (void)
 	"-HAVE_COLOR  "
 #endif
 
-
+	);
+  puts (
 
 #ifdef _PGPPATH
 	"\n"
@@ -608,7 +609,7 @@ int main (int argc, char **argv)
       tempfile = safe_strdup (buf);
 
       if (draftFile)
-	msg->env = mutt_read_rfc822_header (fin, NULL, 1);
+	msg->env = mutt_read_rfc822_header (fin, NULL, 1, 0);
 
       if (tempfile)
       {
